import styled from "styled-components";
import { classes } from "../utils/logic";

export type Props = {
    content?: string,
    icon?: string,
    link?: string,
    primary?: boolean,
    disabled?: boolean,
} & React.ComponentProps<'div'>;

const Button: React.FC<Props> = ({
    content,
    icon,
    link,
    primary,
    children,
    disabled = false,
    ...props
}) => {
    const item = <ButtonStyled {...props} className={classes({ link, primary, disabled })}>
        {icon && <img src={icon} alt="Button icon" />}
        {content || children}
    </ButtonStyled>;

    return (link && !disabled) ? <a href={link} target="_blank" rel="noreferrer">{item}</a> : item;
}

const ButtonStyled = styled.div`
    display: flex;
    align-items: center;
    gap: ${({ theme }) => theme.gap};
    padding: 0.5rem 1rem;
    border: 1px solid ${({ theme }) => theme.border};
    border-radius: 10px;
    transition: 0.2s ease-in-out;
    cursor: default;

    &.link { cursor: pointer; }
    &:active { transform: scale(0.9); }

    img {
        max-width: 20px;
        max-height: 20px;
        transition: filter 0.1s;
        ${({ theme }) => theme.type === 'dark' && 'filter: invert();'}
    }

    &:hover, &.primary {
        background: ${({ theme }) => theme.text};
        color: ${({ theme }) => theme.secondary};
        box-shadow: 0 0 5px ${({ theme }) => theme.text};

        img {
            filter: ${({ theme }) => (theme.type === 'dark' ? 'none' : 'invert()')};
        }
    }

    &.primary:hover {
        background: transparent;
        color: ${({ theme }) => theme.text};

        img { 
            filter: ${({ theme }) => (theme.type === 'dark' ? 'invert()' : 'none')};
        }
    }

    &.disabled {
        opacity: 0.4;
        cursor: not-allowed;
    }
`;

export default Button;