import { Theme } from "styled-components";
import { createContext, useContext, useEffect, useState } from "react";

const defaults = { gap: "1rem" };

export const lightTheme: Theme = {
    ...defaults,
    type: "light",
    primary: "#faf9f6",
    secondary: "#fef9f6",
    border: "#0b1215",
    text: "#000"
};

export const darkTheme: Theme = {
    ...defaults,
    type: "dark",
    primary: "#352f36",
    secondary: "#0c0c0c",
    border: "#fffafa",
    text: "#fff"
};

type Props = {
    theme: Theme,
    toggleTheme: () => void,
};

const ThemeContext = createContext<Props>({
    theme: lightTheme,
    toggleTheme: () => {},
});

const ThemeProvider: React.FC<React.PropsWithChildren> = ({ children }) => {
    const [isLightTheme, setIsLightTheme] = useState(() => localStorage.getItem("theme") === "light");

    useEffect(() => {
        localStorage.setItem("theme", isLightTheme ? "light" : "dark");
    }, [isLightTheme]);

    const theme = isLightTheme ? lightTheme : darkTheme;
    const toggleTheme = () => setIsLightTheme(prev => !prev);

    return (
        <ThemeContext.Provider value={{ theme, toggleTheme }}>
            {children}
        </ThemeContext.Provider>
    );
};

const useTheme = () => useContext<Props>(ThemeContext);

export { useTheme, ThemeProvider };